@@ -138,7 +138,7 @@ function (formula = formula(data),
     
     if (geometric) {
         if (!is.null(frailty))
-            error("Frailty not implemented for geometric yet")
+            stop("Frailty not implemented for geometric yet")
         fit <- geome.fit(X,
                          Y,
                          rs,
@@ -216,8 +216,8 @@ function (formula = formula(data),
                 if (is.null(init)) 
                     temp <- fit$coef[nabeta]
                 else temp <- (fit$coef - init)[nabeta]
-                fit$wald.test <- coxph.wtest(fit$var[nabeta, nabeta], 
-                                             temp, control$toler.chol)$test
+                fit$wald.test <- survival:::coxph.wtest(fit$var[nabeta,
+        nabeta], temp, control$toler.chol)$test
             }
         }
         na.action <- attr(m, "na.action")
